==> ejc-probuilddiary-impl-3.0.0-20220916.091102-6-sources.jar: com/ejianc/business/probuilddiary/project/bean/ProjectLogSafetyEntity.java <==
package com.ejianc.business.probuilddiary.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 项目日志-安全活动情况（安全员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_project_log_safety")
public class ProjectLogSafetyEntity extends BaseEntity {
	private static final long serialVersionUID = 6246961924690293598L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "safety_id")
	private Long safetyId; // 工作类别id
	@TableField(value = "safety_name")
	private String safetyName; // 工作类别名称
	@TableField(value = "safety_code")
	private String safetyCode; // 工作类别编码
	@TableField(value = "safety_memo")
	private String safetyMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "file_type")
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getSafetyId() {
		return safetyId;
	}

	public void setSafetyId(Long safetyId) {
		this.safetyId = safetyId;
	}

	public String getSafetyName() {
		return safetyName;
	}

	public void setSafetyName(String safetyName) {
		this.safetyName = safetyName;
	}

	public String getSafetyCode() {
		return safetyCode;
	}

	public void setSafetyCode(String safetyCode) {
		this.safetyCode = safetyCode;
	}

	public String getSafetyMemo() {
		return safetyMemo;
	}

	public void setSafetyMemo(String safetyMemo) {
		this.safetyMemo = safetyMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-impl-3.0.0-20220919.091720-11-sources.jar: com/ejianc/business/probuilddiary/project/bean/ProjectLogSafetyEntity.java <==
package com.ejianc.business.probuilddiary.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 项目日志-安全活动情况（安全员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_project_log_safety")
public class ProjectLogSafetyEntity extends BaseEntity {
	private static final long serialVersionUID = 6246961924690293598L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "safety_id")
	private Long safetyId; // 工作类别id
	@TableField(value = "safety_name")
	private String safetyName; // 工作类别名称
	@TableField(value = "safety_code")
	private String safetyCode; // 工作类别编码
	@TableField(value = "safety_memo")
	private String safetyMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "update_flag")
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getSafetyId() {
		return safetyId;
	}

	public void setSafetyId(Long safetyId) {
		this.safetyId = safetyId;
	}

	public String getSafetyName() {
		return safetyName;
	}

	public void setSafetyName(String safetyName) {
		this.safetyName = safetyName;
	}

	public String getSafetyCode() {
		return safetyCode;
	}

	public void setSafetyCode(String safetyCode) {
		this.safetyCode = safetyCode;
	}

	public String getSafetyMemo() {
		return safetyMemo;
	}

	public void setSafetyMemo(String safetyMemo) {
		this.safetyMemo = safetyMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
